*****************************************************************************
*** "It's All Relative: Spatial Positioning of Parties and Ideological Shifts": European Journal of Political Research
***
*** Created: 6-24-14
***
*** NOTE: you must run the section "Programs" at the bottom of this file prior to replicating the results!
*****************************************************************************

* Set up working directory
*cd ""

*****************************************************************************
*** Replication
*****************************************************************************
use "It's All Relative.dta", clear

* Simple OLS model
qui reg party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY")), robust cluster(id_elec_count)
keep if e(sample)

sort id_elec_count party

tempfile ast
save `ast', replace

*** Full model at election t-2: absolute proximity (reversed): exponent = 2
preserve
	use "neighbor_proximity_t2_200_tm2", clear
	mkmat var*, matrix(WN)

	use "family_proximity_t2_200_tm2", clear
	mkmat var*, matrix(WF)

	use "proximity_t2_200_tm2", clear
	mkmat var*, matrix(W)
	
	use `ast', clear
	mkmat party_shift_t1, matrix(shift)
	
	mat WNshift = WN*shift
	svmat WNshift
	
	mat WFshift = WF*shift
	svmat WFshift

	mat Wshift = W*shift
	svmat Wshift

	* AS-T Model
	reg party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY")), robust cluster(id_elec_count)
	ols_ar2

	* Model 1
	reg party_shift_t party_shift_t1 medianch1 Wshift WNshift WFshift if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY"))
	ols_ar2
	
	* Model 2
	reg party_shift_t party_shift_t1 medianch1 Wshift WNshift WFshift avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY"))
	ols_ar2
	vif
restore


*****************************************************************************
*** Substantive effects for the predicted ideological movement for Figure 3
*** Use this to hand-input the expected values into the csv file ("shift.csv") and then create the figure in R.
*****************************************************************************
use "It's All Relative.dta", clear

set seed 648

* Simple OLS model
qui reg party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY")), robust cluster(id_elec_count)
keep if e(sample)

sort id_elec_count party

tempfile ast
save `ast', replace

*** AS-T Prediction:
qui sum party_shift_t1
local sd = r(sd)

* 4 parties other than the focal party
estsimp reg party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY")), robust cluster(id_elec_count)
setx mean
setx avg_shift_t1 `sd'/4
simqi, ev listx

setx mean
setx avg_shift_t1 `sd'/4 avg_shift_family_t1 `sd'/4
simqi, ev listx

*** Full model at election t-2: absolute proximity (reversed): exponent = 2
preserve
	local exp = 2		
	
	use "neighbor_proximity_t2_200_tm2", clear
	mkmat var*, matrix(WN)

	use "family_proximity_t2_200_tm2", clear
	mkmat var*, matrix(WF)

	use "proximity_t2_200_tm2", clear
	mkmat var*, matrix(W)
	
	use `ast', clear
	mkmat party_shift_t1, matrix(shift)
	
	mat WNshift = WN*shift
	svmat WNshift
	
	mat WFshift = WF*shift
	svmat WFshift

	mat Wshift = W*shift
	svmat Wshift
	
	reg party_shift_t party_shift_t1 medianch1 Wshift WFshift WNshift if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY"))
	mat list e(b)
	
	ols_ar2
	vif
	
	*** Far left party (-50), 1-standard deviation shift.
	local Wreverse = 131.09
	local shift = 18.8

	local rile = (0 - 50)	
	local arile = abs(`rile')	
	local Wdist = (`Wreverse' - `arile')^`exp'
	
	estsimp reg party_shift_t party_shift_t1 medianch1 Wshift WFshift WNshift if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY"))
	setx WNshift 0
	setx Wshift (`Wdist' * `shift') 
	simqi, ev 
	setx Wshift (`Wdist' * `shift') WFshift (`Wdist' * `shift')
	simqi, ev 
	
	*** Moderate left party (-25), 1-standard deviation
	local rile = (0 - 25)	
	local arile = abs(`rile')	
	local Wdist = (`Wreverse' - `arile')^`exp'

	setx Wshift 0 WFshift 0 WNshift 0
	setx Wshift (`Wdist' * `shift') WNshift (`Wdist' * `shift')
	simqi, ev 
	setx Wshift (`Wdist' * `shift') WNshift (`Wdist' * `shift') WFshift (`Wdist' * `shift')
	simqi, ev 
restore

*****************************************************************************
*** Sample and Descriptive Statistics
*****************************************************************************
use "It's All Relative.dta", clear

* Simple OLS model
qui reg party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1 if old_mapp == 1 & (elec_ts != date("10oct1965","DMY")) & (elec_ts != date("20oct1991","DMY")), robust cluster(id_elec_count)
keep if e(sample)

sort id_elec_count party

sum party_shift_t party_shift_t1 medianch1 avg_shift_t1 avg_shift_family_t1

qui tab ccode 
di "Number of countries = " r(r)
	
qui tab id_elec_count
di "Number of elections = " r(r)

qui tab party
di "Number of parties = " r(r)

preserve
	collapse (count) no_party = party no_elections = id_elec_count (min) min_ts = elec_ts (max) max_ts = elec_ts, by(countryname)
	list 
restore

preserve
	duplicates drop party, force
	collapse (count) no_party = party, by(countryname)
	list 
restore

preserve
	duplicates drop id_elec_count, force
	collapse (count) no_elections = id_elec_count, by(countryname)
	list 
restore

*****************************************************************************
*** Programs
*****************************************************************************
capture program drop ols_ar2
program define ols_ar2
	local ar2 = 1-(1-e(r2))*((e(N)-1)/(e(N)-e(df_m)-1))
	di as result "Adjusted R Squared =  "  `ar2'
	di as result "Root Mean Squared Error = " e(rmse)
	qui estat ic
	mat S = r(S)
	local aic = S[1,5]
	local bic = S[1,6]
	di as result "AIC = " `aic'
	di as result "BIC = " `bic'	
end

